//! Cli interface.

use std::path::PathBuf;

use clap::Parser;
use time::error::Parse;
use time::Date;

use crate::date::FORMAT;

/// Parse a date prvided a a cli argument.
fn parse_date(input: &str) -> Result<Date, Parse> {
    Date::parse(input, FORMAT)
}

/// Download issues of the NZZ newspaper
#[derive(Parser)]
#[command(version, about, long_about = None, after_help = "Provide the authentication cookie from stdin.")]
pub struct Config {
    /// Earliest issue to download (like 1780-12-31)
    #[arg(short, long, env, value_parser=parse_date)]
    pub from: Date,

    /// Latest issue to download (like 1780-12-31)
    #[arg(short, long, env, value_parser=parse_date)]
    pub to: Date,

    /// Output directory.
    #[arg(short, long, env, default_value = "./nzz")]
    pub output_dir: PathBuf,
}
