//! Utilities for handling dates.

use serde::{Deserialize, Deserializer, Serializer};
use time::format_description::FormatItem;
use time::macros::format_description;
use time::Date;

/// Date format for newspaper issues (YYYY-mm-dd)
pub const FORMAT: &[FormatItem<'_>] = format_description!("[year]-[month]-[day]");

/// Serialize a date to a String with serde.
pub fn serialize<S>(value: &Date, serializer: S) -> Result<S::Ok, S::Error>
where
    S: Serializer,
{
    let formated = value.format(&FORMAT).unwrap();
    serializer.serialize_str(&formated)
}

/// Deserialize a String to a Date with serde.
pub fn deserialize<'de, D>(deserializer: D) -> Result<Date, D::Error>
where
    D: Deserializer<'de>,
{
    let s: &str = Deserialize::deserialize(deserializer)?;
    Date::parse(s, FORMAT).map_err(serde::de::Error::custom)
}
